/*
 * $Id: cache.h,v 0.5 1991/08/28 02:21:58 ceder Exp $
 *
 * This file contains the cached data that the server stores.
 * .h file created by ceder 1990-04-18
 */

/* cache_sync_all only returns when everything is written to disk. */
extern void
cache_sync_all(void);


/* First, some things which I want here. /ceder */

extern struct matching_info *match_table;

extern void
cached_lock_conf(Conf_no conf_no);

extern Success
init_cache(void);

extern void
cached_unlock_conf(Conf_no conf);

extern void
cached_lock_person(Pers_no pers);

extern void
cached_unlock_person(Pers_no pers);

extern Success
cached_delete_person(Pers_no pres);

extern Success
cached_delete_text(Text_no text);

extern Success
build_matching_info(void);

extern void			/* Write out everything. */
cache_sync(void);

/* S}d{r ja. Tack f|r mig. /ceder */

#define	MAX_CACHED_PERSONS	5	/* To be increased after debugging */
#define MAX_CACHED_WHATEVER		/* To be added	*/


/*
 * Name caching routines
 */

/*
 * change_name changes the cached conference name. It is only called when
 * a conference name is changed or a conference is deleted.
 *
 * cached_change_name(foo, EMPTY_STRING); should be used when a conference
 * is deleted. (Eller ska det vara annorlunda? S} g|r jag nu... /ceder)
 */
extern void
cached_change_name(Conf_no name_num,
		   String  new_name );


/* add_name adds a name to the list of cached conference names. It is only
 * used when a new conference is created.
 */
extern void
cached_add_name( char * new_name );

/* load all the conference names from disk and store them in memory */
extern void
cached_load_names( void );

#if 0
/* get one name (I want this call! /ceder) */
/* I no longer want it. */
extern String
cached_get_name( Conf_no conf_no );	/* Returns NULL if the conference */
					/* doesn't exist. */
#endif

extern Bool
cached_conf_exists( Conf_no conf_no );

/*
 * Calls for the cacheing of conf_type:
 * cached_get_conf_type() returns the type, and
 * cached_set_conf_type() sets the type.
 */

/* Get conference type */
/* Undefined result if the conf doesn't exist. */

extern Conf_type
cached_get_conf_type (Conf_no conf_no);

/*
 * Set the type. This call is used whenever a conference is created or the
 * conf_type is changed.
 */

extern void
cached_set_conf_type (Conf_no   conf_no,
		      Conf_type type);

/*
 * Get/set garb_nice for a certain conference.
 */
extern Garb_nice
cached_get_garb_nice (Conf_no conf_no);

extern void
cached_set_garb_nice (Conf_no    conf_no,
		      Garb_nice  nice);

extern Local_text_no
cached_get_highest_local_no (Conf_no conf_no);



/*
 * Person caching routines
 */
#if 0
extern Person *
cached_read_person( Pers_no pers_no );
#endif
/*
 * Various function calls to tell the cache that something is changed.
 */

void
mark_person_as_changed(Pers_no	pers_no);


void
mark_conference_as_changed(Conf_no	conf_no);


void
mark_text_as_changed(Text_no	text_no);




/*
 * Person-related calls
 */

extern Success
cached_create_person( Pers_no person );



extern Person *
cached_get_person_stat( Pers_no	person );	/* Returns NULL if person
						   doesn't exist */



/*
 * Conference-related calls
 */
extern Conf_no
cached_create_conf( String  name );


extern Success
cached_delete_conf( Conf_no	conf );

extern Success
cached_lookup_name(const String   name,
		   Conf_list_old *result);

extern Conference *
cached_get_conf_stat(	Conf_no		conf_no );


/*
 * Calls to handle texts
 */

extern String
cached_get_text( Text_no text );/* The string should be free'd by the caller */

extern Text_stat *
cached_get_text_stat(	Text_no		text );


extern Text_no
cached_create_text( String message);

/*
 * traverse_text can be used to cycle through all existing texts. 0 will
 * be returned once in the "cycle".
 */
extern Text_no
traverse_text(Text_no seed);

/*
 * traverse_person can be used to cycle through all existing persons. 0 will
 * be returned once in the "cycle".
 */
extern Pers_no
traverse_person(Pers_no seed);

/*
 * traverse_conference can be used to cycle through all existing conferences.
 * 0 will be returned once in the "cycle".
 */
extern Conf_no
traverse_conference(Conf_no seed);

/*
 * Free all memory used by the cache. This should only be done
 * as part of the shutdown sequence. The purpose of this is to
 * make it possible to see if there are any memory leaks.
 */

void
free_all_cache(void);

/*
 * Limit the number of 'clean' cache entries.
 */
void
cache_limit_size(void);

/*
 * Dump cache statistics.
 */

void
dump_cache_stats(FILE *stat_file);

/*
 * Dump memory usage.
 */
void
dump_cache_mem_usage(FILE *stat_file);
